@@ -86,6 +86,8 @@
 #include "ges.h"
 #include "ges-internal.h"
 
+#define GLIB_DISABLE_DEPRECATION_WARNINGS
+
 #include <gst/gst.h>
 
 GST_DEBUG_CATEGORY_STATIC (ges_asset_debug);
@@ -119,7 +121,7 @@ struct _GESAssetPrivate
   GESAssetState state;
   GType extractable_type;
 
-  /* When an asset is proxied, instanciating it will
+  /* When an asset is proxied, instantiating it will
    * return the asset it points to */
   char *proxied_asset_id;
 
@@ -288,15 +290,38 @@ ges_asset_extract_default (GESAsset * asset, GError ** error)
   GESAssetPrivate *priv = asset->priv;
   GESExtractable *n_extractable;
 
+
   params = ges_extractable_type_get_parameters_from_id (priv->extractable_type,
       priv->id, &n_params);
 
+#if GLIB_CHECK_VERSION(2, 53, 1)
+  {
+    gint i;
+    GValue *values;
+    const gchar **names;
+
+    values = g_malloc0 (sizeof (GValue) * n_params);
+    names = g_malloc0 (sizeof (gchar *) * n_params);
+
+    for (i = 0; i < n_params; i++) {
+      values[i] = params[i].value;
+      names[i] = params[i].name;
+    }
+
+    n_extractable =
+        GES_EXTRACTABLE (g_object_new_with_properties (priv->extractable_type,
+            n_params, names, values));
+    g_free (names);
+    g_free (values);
+  }
+#else
   n_extractable = g_object_newv (priv->extractable_type, n_params, params);
+#endif
 
   while (n_params--)
     g_value_unset (&params[n_params].value);
-  if (params)
-    g_free (params);
+
+  g_free (params);
 
   return n_extractable;
 }
@@ -616,6 +641,8 @@ gboolean
 ges_asset_request_id_update (GESAsset * asset, gchar ** proposed_id,
     GError * error)
 {
+  g_return_val_if_fail (GES_IS_ASSET (asset), FALSE);
+
   return GES_ASSET_GET_CLASS (asset)->request_id_update (asset, proposed_id,
       error);
 }
@@ -625,6 +652,8 @@ ges_asset_try_proxy (GESAsset * asset, const gchar * new_id)
 {
   GESAssetClass *class;
 
+  g_return_val_if_fail (GES_IS_ASSET (asset), FALSE);
+
   if (g_strcmp0 (asset->priv->id, new_id) == 0) {
     GST_WARNING_OBJECT (asset, "Trying to proxy to itself (%s),"
         " NOT possible", new_id);
@@ -754,6 +783,37 @@ ges_asset_set_proxy (GESAsset * asset, GESAsset * proxy)
   return TRUE;
 }
 
+/**
+ * ges_asset_unproxy:
+ * @asset: The #GESAsset to stop proxying with @proxy
+ * @proxy: The #GESAsset to stop considering as a proxy for @asset
+ *
+ * Removes @proxy from the list of known proxies for @asset.
+ * If @proxy was the current proxy for @asset, stop using it.
+ *
+ * Returns: %TRUE if @proxy was a known proxy for @asset, %FALSE otherwise.
+ */
+gboolean
+ges_asset_unproxy (GESAsset * asset, GESAsset * proxy)
+{
+  g_return_val_if_fail (GES_IS_ASSET (asset), FALSE);
+  g_return_val_if_fail (GES_IS_ASSET (proxy), FALSE);
+  g_return_val_if_fail (asset != proxy, FALSE);
+
+  if (!g_list_find (asset->priv->proxies, proxy)) {
+    GST_INFO_OBJECT (asset, "%s is not a proxy.", proxy->priv->id);
+
+    return FALSE;
+  }
+
+  if (asset->priv->proxies->data == proxy)
+    ges_asset_set_proxy (asset, NULL);
+
+  asset->priv->proxies = g_list_remove (asset->priv->proxies, proxy);
+
+  return TRUE;
+}
+
 /**
  * ges_asset_list_proxies:
  * @asset: The #GESAsset to get proxies from
@@ -812,7 +872,11 @@ ges_asset_set_id (GESAsset * asset, const gchar * id)
 
   gpointer orig_id = NULL;
   GESAssetCacheEntry *entry = NULL;
-  GESAssetPrivate *priv = asset->priv;
+  GESAssetPrivate *priv = NULL;
+
+  g_return_if_fail (GES_IS_ASSET (asset));
+
+  priv = asset->priv;
 
   if (priv->state != ASSET_INITIALIZED) {
     GST_WARNING_OBJECT (asset, "Trying to rest ID on an object that is"
@@ -879,6 +943,8 @@ _unsure_material_for_wrong_id (const gchar * wrong_id, GType extractable_type,
 GType
 ges_asset_get_extractable_type (GESAsset * self)
 {
+  g_return_val_if_fail (GES_IS_ASSET (self), G_TYPE_INVALID);
+
   return self->priv->extractable_type;
 }
 
@@ -917,6 +983,8 @@ ges_asset_request (GType extractable_type, const gchar * id, GError ** error)
     _unsure_material_for_wrong_id (id, extractable_type, lerr);
     real_id = g_strdup (id);
   }
+  if (lerr)
+    g_error_free (lerr);
 
   asset = ges_asset_cache_lookup (extractable_type, real_id);
   if (asset) {
@@ -1157,6 +1225,7 @@ ges_asset_needs_reload (GType extractable_type, const gchar * id)
         "Asset with id %s switch state to ASSET_NEEDS_RELOAD",
         ges_asset_get_id (asset));
     asset->priv->state = ASSET_NEEDS_RELOAD;
+    g_clear_error (&asset->priv->error);
     return TRUE;
   }
 
