@@ -19,6 +19,7 @@
 
 /**
  * SECTION:gesgroup
+ * @title: GESGroup
  * @short_description: Class that permits to group GESClip-s in a timeline,
  * letting the user manage it a single GESTimelineElement
  *
@@ -90,7 +91,12 @@ _update_our_values (GESGroup * group)
 
     if (GES_IS_CLIP (child)) {
       GESLayer *layer = ges_clip_get_layer (GES_CLIP (child));
-      gint32 prio = ges_layer_get_priority (layer);
+      gint32 prio;
+
+      if (!layer)
+        continue;
+
+      prio = ges_layer_get_priority (layer);
 
       min_layer_prio = MIN (prio, min_layer_prio);
       max_layer_prio = MAX (prio, max_layer_prio);
@@ -182,13 +188,14 @@ _child_clip_changed_layer_cb (GESTimelineElement * clip,
     return;
   }
 
-  if (new_layer && (layer_prio + offset < 0 ||
+  if (new_layer && old_layer && (layer_prio + offset < 0 ||
           (GES_TIMELINE_ELEMENT_TIMELINE (group) &&
               layer_prio + offset + GES_CONTAINER_HEIGHT (group) - 1 >
               g_list_length (GES_TIMELINE_ELEMENT_TIMELINE (group)->layers)))) {
 
-    GST_INFO_OBJECT (container, "Trying to move to a layer outside of"
-        "the timeline layers, moving back to old layer (prio %i)",
+    GST_INFO_OBJECT (container,
+        "Trying to move to a layer %" GST_PTR_FORMAT " outside of"
+        "the timeline layers, moving back to old layer (prio %i)", new_layer,
         _PRIORITY (group) - offset);
 
     container->children_control_mode = GES_CHILDREN_INIBIT_SIGNAL_EMISSION;
@@ -198,6 +205,12 @@ _child_clip_changed_layer_cb (GESTimelineElement * clip,
     return;
   }
 
+  if (!new_layer || !old_layer) {
+    _update_our_values (group);
+
+    return;
+  }
+
   container->initiated_move = clip;
   _set_priority0 (GES_TIMELINE_ELEMENT (group), layer_prio + offset);
   container->initiated_move = NULL;
