@@ -68,7 +68,7 @@ struct _GESImageSourceClass {
   gpointer _ges_reserved[GES_PADDING];
 };
 
-GST_EXPORT
+GES_API
 GType ges_image_source_get_type (void);
 
 G_END_DECLS
