@@ -44,6 +44,7 @@ GST_DEBUG_CATEGORY_STATIC (ges_pipeline_debug);
 
 #define DEFAULT_TIMELINE_MODE  GES_PIPELINE_MODE_PREVIEW
 #define IN_RENDERING_MODE(timeline) ((timeline->priv->mode) & (GES_PIPELINE_MODE_RENDER | GES_PIPELINE_MODE_SMART_RENDER))
+#define CHECK_THREAD(pipeline) g_assert(pipeline->priv->valid_thread == g_thread_self())
 
 /* Structure corresponding to a timeline - sink link */
 
@@ -74,6 +75,8 @@ struct _GESPipelinePrivate
   GList *not_rendered_tracks;
 
   GstEncodingProfile *profile;
+
+  GThread *valid_thread;
 };
 
 enum
@@ -370,6 +373,7 @@ ges_pipeline_init (GESPipeline * self)
   GST_INFO_OBJECT (self, "Creating new 'playsink'");
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
       GES_TYPE_PIPELINE, GESPipelinePrivate);
+  self->priv->valid_thread = g_thread_self ();
 
   self->priv->playsink =
       gst_element_factory_make ("playsink", "internal-sinks");
@@ -1015,6 +1019,7 @@ ges_pipeline_set_timeline (GESPipeline * pipeline, GESTimeline * timeline)
   g_return_val_if_fail (GES_IS_PIPELINE (pipeline), FALSE);
   g_return_val_if_fail (GES_IS_TIMELINE (timeline), FALSE);
   g_return_val_if_fail (pipeline->priv->timeline == NULL, FALSE);
+  CHECK_THREAD (pipeline);
 
   GST_DEBUG ("pipeline:%p, timeline:%p", timeline, pipeline);
 
@@ -1058,6 +1063,7 @@ ges_pipeline_set_render_settings (GESPipeline * pipeline,
   GstEncodingProfile *set_profile;
 
   g_return_val_if_fail (GES_IS_PIPELINE (pipeline), FALSE);
+  CHECK_THREAD (pipeline);
 
   /*  FIXME Properly handle multi track, for now GESPipeline
    *  only hanles single track per type, so we should just set the
@@ -1157,6 +1163,7 @@ ges_pipeline_set_mode (GESPipeline * pipeline, GESPipelineFlags mode)
 
   GList *tmp;
   g_return_val_if_fail (GES_IS_PIPELINE (pipeline), FALSE);
+  CHECK_THREAD (pipeline);
 
   GST_DEBUG_OBJECT (pipeline, "current mode : %d, mode : %d",
       pipeline->priv->mode, mode);
@@ -1283,6 +1290,7 @@ ges_pipeline_get_thumbnail (GESPipeline * self, GstCaps * caps)
   GstElement *sink;
 
   g_return_val_if_fail (GES_IS_PIPELINE (self), FALSE);
+  CHECK_THREAD (self);
 
   sink = self->priv->playsink;
 
@@ -1320,6 +1328,7 @@ ges_pipeline_save_thumbnail (GESPipeline * self, int width, int
   gboolean res = TRUE;
 
   g_return_val_if_fail (GES_IS_PIPELINE (self), FALSE);
+  CHECK_THREAD (self);
 
   caps = gst_caps_from_string (format);
 
@@ -1376,6 +1385,7 @@ ges_pipeline_get_thumbnail_rgb24 (GESPipeline * self, gint width, gint height)
   GstCaps *caps;
 
   g_return_val_if_fail (GES_IS_PIPELINE (self), FALSE);
+  CHECK_THREAD (self);
 
   caps = gst_caps_new_simple ("video/x-raw", "format", G_TYPE_STRING,
       "RGB", NULL);
@@ -1409,6 +1419,7 @@ ges_pipeline_preview_get_video_sink (GESPipeline * self)
   GstElement *sink = NULL;
 
   g_return_val_if_fail (GES_IS_PIPELINE (self), FALSE);
+  CHECK_THREAD (self);
 
   g_object_get (self->priv->playsink, "video-sink", &sink, NULL);
 
@@ -1427,6 +1438,7 @@ void
 ges_pipeline_preview_set_video_sink (GESPipeline * self, GstElement * sink)
 {
   g_return_if_fail (GES_IS_PIPELINE (self));
+  CHECK_THREAD (self);
 
   g_object_set (self->priv->playsink, "video-sink", sink, NULL);
 };
@@ -1449,6 +1461,7 @@ ges_pipeline_preview_get_audio_sink (GESPipeline * self)
   GstElement *sink = NULL;
 
   g_return_val_if_fail (GES_IS_PIPELINE (self), FALSE);
+  CHECK_THREAD (self);
 
   g_object_get (self->priv->playsink, "audio-sink", &sink, NULL);
 
@@ -1467,6 +1480,7 @@ void
 ges_pipeline_preview_set_audio_sink (GESPipeline * self, GstElement * sink)
 {
   g_return_if_fail (GES_IS_PIPELINE (self));
+  CHECK_THREAD (self);
 
   g_object_set (self->priv->playsink, "audio-sink", sink, NULL);
 };
