@@ -19,6 +19,7 @@
  */
 /**
  * SECTION: gesproject
+ * @title: GESProject
  * @short_description: A GESAsset that is used to manage projects
  *
  * The #GESProject is used to control a set of #GESAsset and is a
@@ -312,6 +313,13 @@ ges_missing_uri_default (GESProject * self, GError * error,
 {
   guint i;
   const gchar *old_uri = ges_asset_get_id (wrong_asset);
+  gchar *new_id = NULL;
+
+  if (ges_asset_request_id_update (wrong_asset, &new_id, error) && new_id) {
+    GST_INFO_OBJECT (self, "Returned guessed new ID: %s", new_id);
+
+    return new_id;
+  }
 
   if (new_paths == NULL)
     return NULL;
@@ -587,11 +595,10 @@ ges_project_try_updating_id (GESProject * project, GESAsset * asset,
     return NULL;
   }
 
-  if (new_id == NULL) {
-    GST_DEBUG_OBJECT (project, "Sending 'missing-uri' signal for %s", id);
-    g_signal_emit (project, _signals[MISSING_URI_SIGNAL], 0, error, asset,
-        &new_id);
-  }
+  /* Always send the MISSING_URI signal if requesting new ID is possible
+   * so that subclasses of GESProject are aware of the missing-uri */
+  g_signal_emit (project, _signals[MISSING_URI_SIGNAL], 0, error, asset,
+      &new_id);
 
   if (new_id) {
     GST_DEBUG_OBJECT (project, "new id found: %s", new_id);
@@ -789,8 +796,7 @@ ges_project_create_asset_sync (GESProject * project, const gchar * id,
       if (possible_id == NULL)
         return NULL;
 
-      if (error)
-        g_clear_error (error);
+      g_clear_error (error);
 
       id = possible_id;
     }
