@@ -77,7 +77,7 @@ struct _GESSourceClass {
   gpointer _ges_reserved[GES_PADDING];
 };
 
-GST_EXPORT
+GES_API
 GType ges_source_get_type (void);
 
 G_END_DECLS
