@@ -54,10 +54,10 @@ struct _GESVideoTrack
   gpointer    _ges_reserved[GES_PADDING];
 };
 
-GST_EXPORT
+GES_API
 GType ges_video_track_get_type (void) G_GNUC_CONST;
 
-GST_EXPORT
+GES_API
 GESVideoTrack * ges_video_track_new (void);
 
 G_END_DECLS
