@@ -20,6 +20,7 @@
 
 /**
  * SECTION:gesvideotransition
+ * @title: GESVideoTransition
  * @short_description: implements video crossfade transition
  */
 
@@ -49,8 +50,7 @@ struct _GESVideoTransitionPrivate
   GESVideoStandardTransitionType pending_type;
 
   /* these enable video interpolation */
-  GstTimedValueControlSource *fade_in_control_source;
-  GstTimedValueControlSource *fade_out_control_source;
+  GstTimedValueControlSource *crossfade_control_source;
   GstTimedValueControlSource *smpte_control_source;
 
   /* so we can support changing between wipes */
@@ -62,6 +62,9 @@ struct _GESVideoTransitionPrivate
   GstPad *mixer_sinka;
   GstPad *mixer_sinkb;
 
+  GstPad *mixer_ghosta;
+  GstPad *mixer_ghostb;
+
   /* This is in case the smpte doesn't exist yet */
   gint pending_border_value;
   gboolean pending_inverted;
@@ -84,7 +87,7 @@ static GParamSpec *properties[PROP_LAST];
 
 static GObject *link_element_to_mixer_with_smpte (GstBin * bin,
     GstElement * element, GstElement * mixer, gint type,
-    GstElement ** smpteref, GESVideoTransitionPrivate * priv);
+    GstElement ** smpteref, GESVideoTransitionPrivate * priv, GstPad ** ghost);
 
 static void
 ges_video_transition_duration_changed (GESTrackElement * self,
@@ -189,8 +192,7 @@ ges_video_transition_init (GESVideoTransition * self)
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
       GES_TYPE_VIDEO_TRANSITION, GESVideoTransitionPrivate);
 
-  self->priv->fade_in_control_source = NULL;
-  self->priv->fade_out_control_source = NULL;
+  self->priv->crossfade_control_source = NULL;
   self->priv->smpte_control_source = NULL;
   self->priv->smpte = NULL;
   self->priv->mixer_sink = NULL;
@@ -228,14 +230,9 @@ ges_video_transition_dispose (GObject * object)
 
   GST_DEBUG ("disposing");
 
-  if (priv->fade_in_control_source) {
-    gst_object_unref (priv->fade_in_control_source);
-    priv->fade_in_control_source = NULL;
-  }
-
-  if (priv->fade_out_control_source) {
-    gst_object_unref (priv->fade_out_control_source);
-    priv->fade_out_control_source = NULL;
+  if (priv->crossfade_control_source) {
+    gst_object_unref (priv->crossfade_control_source);
+    priv->crossfade_control_source = NULL;
   }
 
   if (priv->smpte_control_source) {
@@ -243,7 +240,7 @@ ges_video_transition_dispose (GObject * object)
     priv->smpte_control_source = NULL;
   }
 
-  release_mixer (&priv->mixer, &priv->mixer_sinka, &priv->mixer_sinkb);
+  release_mixer (&priv->mixer, &priv->mixer_ghosta, &priv->mixer_ghostb);
 
   g_signal_handlers_disconnect_by_func (GES_TRACK_ELEMENT (self),
       duration_changed_cb, NULL);
@@ -303,14 +300,17 @@ ges_video_transition_set_property (GObject * object,
 
 static GstTimedValueControlSource *
 set_interpolation (GstObject * element, GESVideoTransitionPrivate * priv,
-    const gchar * propname)
+    const gchar * propname, gboolean absolute)
 {
   GstControlSource *control_source;
 
   g_object_set (element, propname, (gfloat) 0.0, NULL);
 
   control_source = gst_interpolation_control_source_new ();
+
   gst_object_add_control_binding (GST_OBJECT (element),
+      absolute ? gst_direct_control_binding_new_absolute (GST_OBJECT (element),
+          propname, control_source) :
       gst_direct_control_binding_new (GST_OBJECT (element), propname,
           control_source));
   g_object_set (control_source, "mode", GST_INTERPOLATION_MODE_LINEAR, NULL);
@@ -334,8 +334,14 @@ ges_video_transition_create_element (GESTrackElement * object)
 
   topbin = gst_bin_new ("transition-bin");
 
-  iconva = gst_element_factory_make ("videoconvert", "tr-csp-a");
-  iconvb = gst_element_factory_make ("videoconvert", "tr-csp-b");
+  iconva =
+      gst_parse_bin_from_description
+      ("videoconvert ! capsfilter caps=\"video/x-raw,format=BGRA\"", TRUE,
+      NULL);
+  iconvb =
+      gst_parse_bin_from_description
+      ("videoconvert ! capsfilter caps=\"video/x-raw,format=BGRA\"", TRUE,
+      NULL);
   priv->positioner =
       gst_element_factory_make ("framepositioner", "frame_tagger");
   g_object_set (priv->positioner, "zorder",
@@ -345,18 +351,21 @@ ges_video_transition_create_element (GESTrackElement * object)
   gst_bin_add_many (GST_BIN (topbin), iconva, iconvb, priv->positioner,
       oconv, NULL);
 
-  mixer = ges_smart_mixer_new (NULL);
+  mixer =
+      g_object_new (GES_TYPE_SMART_MIXER, "name",
+      GES_TIMELINE_ELEMENT_NAME (self), NULL);
   g_object_set (GES_SMART_MIXER (mixer)->mixer, "background", 3, NULL);
   GES_SMART_MIXER (mixer)->disable_zorder_alpha = TRUE;
   gst_bin_add (GST_BIN (topbin), mixer);
 
   priv->mixer_sinka =
       (GstPad *) link_element_to_mixer_with_smpte (GST_BIN (topbin), iconva,
-      mixer, GES_VIDEO_STANDARD_TRANSITION_TYPE_BAR_WIPE_LR, NULL, priv);
+      mixer, GES_VIDEO_STANDARD_TRANSITION_TYPE_BAR_WIPE_LR, NULL, priv,
+      &priv->mixer_ghosta);
   priv->mixer_sinkb =
       (GstPad *) link_element_to_mixer_with_smpte (GST_BIN (topbin), iconvb,
       mixer, GES_VIDEO_STANDARD_TRANSITION_TYPE_BAR_WIPE_LR, &priv->smpte,
-      priv);
+      priv, &priv->mixer_ghostb);
   g_object_set (priv->mixer_sinka, "zorder", 0, NULL);
   g_object_set (priv->mixer_sinkb, "zorder", 1, NULL);
 
@@ -381,12 +390,11 @@ ges_video_transition_create_element (GESTrackElement * object)
 
   /* set up interpolation */
 
-  priv->fade_out_control_source =
-      set_interpolation (GST_OBJECT (priv->mixer_sinka), priv, "alpha");
-  priv->fade_in_control_source =
-      set_interpolation (GST_OBJECT (priv->mixer_sinkb), priv, "alpha");
+  priv->crossfade_control_source =
+      set_interpolation (GST_OBJECT (priv->mixer_sinka), priv,
+      "crossfade-ratio", TRUE);
   priv->smpte_control_source =
-      set_interpolation (GST_OBJECT (priv->smpte), priv, "position");
+      set_interpolation (GST_OBJECT (priv->smpte), priv, "position", FALSE);
   priv->mixer = gst_object_ref (mixer);
 
   if (priv->pending_type)
@@ -409,9 +417,9 @@ ges_video_transition_create_element (GESTrackElement * object)
 static GObject *
 link_element_to_mixer_with_smpte (GstBin * bin, GstElement * element,
     GstElement * mixer, gint type, GstElement ** smpteref,
-    GESVideoTransitionPrivate * priv)
+    GESVideoTransitionPrivate * priv, GstPad ** ghost)
 {
-  GstPad *srcpad, *sinkpad, *mixerpad;
+  GstPad *srcpad, *mixerpad;
   GstElement *smptealpha = gst_element_factory_make ("smptealpha", NULL);
 
   g_object_set (G_OBJECT (smptealpha),
@@ -427,8 +435,8 @@ link_element_to_mixer_with_smpte (GstBin * bin, GstElement * element,
   }
 
   srcpad = gst_element_get_static_pad (smptealpha, "src");
-  sinkpad = ges_smart_mixer_get_mixer_pad (GES_SMART_MIXER (mixer), &mixerpad);
-  gst_pad_link_full (srcpad, sinkpad, GST_PAD_LINK_CHECK_NOTHING);
+  *ghost = ges_smart_mixer_get_mixer_pad (GES_SMART_MIXER (mixer), &mixerpad);
+  gst_pad_link_full (srcpad, *ghost, GST_PAD_LINK_CHECK_NOTHING);
   gst_object_unref (srcpad);
 
   return G_OBJECT (mixerpad);
@@ -445,7 +453,7 @@ ges_video_transition_update_control_source (GstTimedValueControlSource * ts,
 
 static void
 ges_video_transition_update_control_sources (GESVideoTransition * self,
-        GESVideoStandardTransitionType type)
+    GESVideoStandardTransitionType type)
 {
   GESVideoTransitionPrivate *priv = self->priv;
   guint64 duration =
@@ -454,16 +462,12 @@ ges_video_transition_update_control_sources (GESVideoTransition * self,
   GST_LOG ("updating controller");
   if (type == GES_VIDEO_STANDARD_TRANSITION_TYPE_CROSSFADE) {
     ges_video_transition_update_control_source
-        (priv->fade_in_control_source, duration, 0.0, 1.0);
-    ges_video_transition_update_control_source
-        (priv->fade_out_control_source, duration, 1.0, 0.0);
+        (priv->crossfade_control_source, duration, 1.0, 0.0);
     ges_video_transition_update_control_source (priv->smpte_control_source,
         duration, 0.0, 0.0);
   } else {
     ges_video_transition_update_control_source
-        (priv->fade_in_control_source, duration, 1.0, 1.0);
-    ges_video_transition_update_control_source
-        (priv->fade_out_control_source, duration, 1.0, 1.0);
+        (priv->crossfade_control_source, duration, -1.0, -1.0);
     ges_video_transition_update_control_source (priv->smpte_control_source,
         duration, 1.0, 0.0);
   }
