@@ -763,6 +763,10 @@ gnonlin_suite (void)
   Suite *s = suite_create ("gnonlin-simple");
   TCase *tc_chain = tcase_create ("general");
 
+  if (atexit (ges_deinit) != 0) {
+    GST_ERROR ("failed to set ges_deinit as exit function");
+  }
+
   suite_add_tcase (s, tc_chain);
 
   ges_init ();
